PROC IMPORT OUT=mcafile
            DATAFILE= "h:\Alexandre\Artigos\Livro\Mexico\MCABrazil80_00.xls" 
            DBMS=EXCEL5 REPLACE;
     GETNAMES=YES;
RUN;

PROC FREQ DATA=mcafile;
  TABLE fu*year;
 RUN;

 /* MQO */
PROC GLM DATA=mcafile;
     CLASS mca year;
     MODEL lnwage = pr unr ir udr 
					a20_29 a30_39 a40_49 a50_59 a60 e1 e2 e3 wmp whp 
					i1 i2 i3 i4 i5 
					o1 o2 o3 o4 o5 o6 o7 o8 
                    mca year / SOLUTION;
     OUTPUT OUT=outols RESIDUAL=resid;
	 WHERE fu=43;
RUN;
quit;

ods rtf file='H:\Alexandre\Artigos\Livro\Mexico\Variogram.rtf';
ods graphics on;

/* SEMIVARIOGRAM TO MQO RESIDUALS */
proc variogram data=outols; 
  compute lagd = 10 maxlag = 20 cl; 
  coordinates xc=long yc=lat; 
  var resid; 
run;
quit;

ods graphics off;
ods rtf close;

data pv;
  do Distance = 0 to 200 by 1;
    Semivariance = .;
    output;
  end;
run;
data sv; set sv pv; by Distance;
run;
proc nlin data=sv; 
  parms Range=150 Sill=0.014; nugget=0.012;
  model Semivariance = nugget+Sill*(1-exp(-Distance*Distance/(Range*Range)));
  output out=OLS p=OLS;
run;

ods rtf file='g:\alexandre\artigos\rsai\review\AdjustedXObserved.rtf';

ods graphics on;

data ols2;
  set ols;
  label semivariance="Observed";
  label ols="Fitted";
run;

goptions noborder;
proc sgplot data=ols2;
      title "";
      xaxis label = "Distance" grid;
      yaxis label = "Semivariance" grid;
      scatter y=Semivariance x=Distance /
              markerattrs = GraphData1(symbol=circle)
              name = 'Observed';
      series x=Distance y=OLS /
             lineattrs = (thickness=2px color=black
                          pattern=MediumDash)
             name = 'Fitted'; 
      discretelegend 'Observed' 'Fitted';
 run; 
 quit;

ods graphics off;
ods rtf close;

proc gplot data=ols; 
  plot semivariance*distance ols*distance/overlay; 
run;
quit;

/* JUST FIXED EFFECTS */
options fullstimer ;
proc mixed data=tmp_02 noclprint scoring=50;
  class ano v0103;
  parms (0.014) (104.1) (0.012);
  model lnrenda = tp td tinfomal tunder
                  po20a29 po30a39 po40a49 po50a59 po60
				  poesc1 poesc2 poesc3
				  pofem pobranco
				  poativ2 poativ3 poativ4 poativ5 poativ6 
				  poocc1 poocc2 poocc3 poocc5 poocc6 poocc7 poocc8 poocc9
                  ano V0103/solution outp=reprsai.saida2;
*  random intercept / subject=v0103 solution;
  repeated / subject = ano local type = sp(gau)(x y);
  ods output Solutionf= reprsai.Fixed2;
*  ods output SolutionR= Random;
*  where ano=2000;
run;
quit;
PROC EXPORT DATA=reprsai.Fixed2
            OUTFILE= "f:\Alexandre\Artigos\rsai\review\OutputSAC.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;



/* REPEAT MCA VARIABLES FOR EACH MUNICIPALITIE IN THE GROUP */
proc sql;
  create table FixedEffects as
  select a.ufmun as codibg97,
         a.nomemun as nom,
		 b.estimate as estimate
  from amc2 as a 
  left join reprsai.fixed2 as b on b.v0103=a.codmunic
  where b.v0103 gt 1100000 and b.v0103 lt 5300000;
quit;

PROC EXPORT DATA=FixedEffects
            OUTFILE= "f:\Alexandre\Artigos\rsai\review\ResidualsSAC.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;




/* GENERATE DATA FOR SPATIAL DISTRIBUTION OF CLASSES */
proc sql;
  create table tbr_80 as
    select b.codibg01 as codibg97, a.amc, b.nom, 
           a.ano,
		   a.npessoas,
		   a.np10,
		   a.np65,
		   a.nornd,
		   a.tp, a.td, a.tinfomal, a.tunder, a.po10a24, a.po60, a.phighs, a.pofem, a.pobranco, 

	       a.rndtrabr,
	       a.rndaposr,
	       a.rndoutrr,
	       sum(a.rndtrabr, a.rndaposr, a.rndoutrr) as rndtotr,
	       a.nprnd,
	       a.ndrnd,
	       a.rdpctr,
	       a.rdpcr,
	       a.rdptrabr,
	       a.rdpaposr,
	       a.rdpoutrr,
           a.rndtrabr/sum(a.rndtrabr,a.rndaposr,a.rndoutrr)*100 as prndtrab,
           a.rndaposr/sum(a.rndtrabr,a.rndaposr,a.rndoutrr)*100 as prndapos,
           a.rndoutrr/sum(a.rndtrabr,a.rndaposr,a.rndoutrr)*100 as prndoutr,
		   a.rmptrabr

/*		   a.yhat,
		   a.e*/
    from reprsai.tbr_80 as a
    left join reprsai.dtb as b on b.codibg01=int(a.v0103/10);
quit;



/* CALCULA DECIS DE RENDA PER CAPITA */
%macro decis(input, output);

  proc sql;
    create table tmp_00 as
    select count(*) as nmunic 
    from &input;
  quit;
  data _null_;
    set tmp_00;
	call symput('NMUNIC',nmunic);
  run;

  proc sort data=&input out=tmp_01a;
    by rmptrabr;
  data &output;
    set tmp_01a;
	drop ordem;
	retain ordem 0;
	ordem=ordem+1;

	decil=int(ordem/((symget('NMUNIC')+1)/10))+1;
  run;

%fora: %mend decis;


%decis(TBR_00, DBR_00);

PROC EXPORT DATA=dbr_00
            OUTFILE= "C:\Alexandre\Artigos\aber\2009\Dbr_00.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;

%decis(TBR_91, DBR_91);

PROC EXPORT DATA=dbr_91
            OUTFILE= "C:\Alexandre\Artigos\aber\2009\Dbr_91.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;

/*%decis(TBR_91, DBR_91);*/
%decis(TBR_80, DBR_80);


PROC EXPORT DATA=dbr_80
            OUTFILE= "C:\Alexandre\Artigos\aber\2009\Dbr_80.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;

data reprsai.dbr_80to00;
  set dbr_80 dbr_91 dbr_00;
run;


/* REPEAT MCA VARIABLES FOR EACH MUNICIPALITIE IN THE GROUP */
proc sql;
  create table dbr_80to00 as
  select a.ufmun as codibg97,
         a.nomemun as nom,
		 b.rmptrabr as rmptr80,
		 c.rmptrabr as rmptr91,
		 d.rmptrabr as rmptr00,
		 b.e as e80,
		 c.e as e91,
		 d.e as e00
  from amc2 as a
  left join dbr_80 as b on b.codibg97=int(a.codmunic/10)
  left join dbr_91 as c on c.codibg97=int(a.codmunic/10)
  left join dbr_00 as d on d.codibg97=int(a.codmunic/10);
quit;


PROC EXPORT DATA=dbr_80to00
            OUTFILE= "C:\Alexandre\Artigos\aber\2009\Dbr_80to00.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;



/* EVALUATE BETWEEN MUNICIPALITIES WAGE INEQUALITY */
%macro theilb(year, input, output, income, total);


  /* COMPUTE TOTAL AND BETWEEN MUNICIPALITIES WAGE INEQUALITY */
  proc sql;
    create table &output as
      select &year as ano,
             sum(a.p001p*a.&income/b.tearn*log(b.tpearn*a.&income/b.tearn)) as ttheil,
		     c.tbetween as tbetween1, d.tbetween as tbetween2, e.tbetween as tbetween3
  	  from &input as a,

	        /* total income and persons with income */
	       (select sum(&income*p001p) as tearn, sum(p001p) as tpearn
	        from &input
	        where &income gt 0 and (condativ=2 or &total=1)) as b,

			/* theil between municipalities */
	       (select sum(ca.tgearn/cb.tearn*log((ca.tgearn/cb.tearn)/(ca.tgpearn/cb.tpearn))) as tbetween
		    from (select v0103, sum(&income*p001p) as tgearn, sum(p001p) as tgpearn
	              from &input
	              where &income gt 0 and (condativ=2 or &total=1)
                  group by v0103) as ca,
                 (select sum(&income*p001p) as tearn, sum(p001p) as tpearn
	              from &input
	              where &income gt 0 and (condativ=2 or &total=1)) as cb) as c,

			/* theil between states */
	       (select sum(da.tgearn/db.tearn*log((da.tgearn/db.tearn)/(da.tgpearn/db.tpearn))) as tbetween
		    from (select uf, sum(&income*p001p) as tgearn, sum(p001p) as tgpearn
	              from &input
	              where &income gt 0 and (condativ=2 or &total=1)
                  group by uf) as da,
                 (select sum(&income*p001p) as tearn, sum(p001p) as tpearn
	              from &input
	              where &income gt 0 and (condativ=2 or &total=1)) as db) as d,

			/* theil between regions */
	       (select sum(ea.tgearn/eb.tearn*log((ea.tgearn/eb.tearn)/(ea.tgpearn/eb.tpearn))) as tbetween
		    from (select case 
			               when uf ge 11 and uf le 17 then 1
						   when uf ge 21 and uf le 29 then 2
						   when uf ge 31 and uf le 35 then 3
						   when uf ge 41 and uf le 43 then 4
						   when uf ge 50 and uf le 53 then 5
                         end as regiao, 
                         sum(&income*p001p) as tgearn, sum(p001p) as tgpearn
	              from &input
	              where &income gt 0 and (condativ=2 or &total=1)
                  group by 1) as ea,
                 (select sum(&income*p001p) as tearn, sum(p001p) as tpearn
	              from &input
	              where &income gt 0 and (condativ=2 or &total=1)) as eb) as e

	  where a.&income gt 0 and (condativ=2 or &total=1);
  quit;


%fora: %mend theilb;


/* EVALUATE WITHIN MUNICIPALITIES WAGE INEQUALITY */
%macro theilw(year, input, output, income, total);


  /* COMPUTE WITHIN MUNICIPALITIES WAGE INEQUALITY */
  proc sql;
    create table &output as
      select &year as ano, a.v0103,
             sum(a.p001p*a.&income/b.tearn*log(b.tpearn*a.&income/b.tearn)) as ttheil
  	  from &input as a,

	        /* total income and persons with income */
	       (select v0103, sum(&income*p001p) as tearn, sum(p001p) as tpearn
	        from &input
	        where &income gt 0 and (condativ=2 or &total=1)
            group by v0103) as b

	  where a.&income gt 0 and (a.condativ=2 or &total=1) and b.v0103=a.v0103
      group by a.v0103;
  quit;


%fora: %mend theilw;


*%theilb(2000, reprsai.BR_00, reprsai.Theil1_00, rndtrabr, 0);
%theilb(1991, reprsai.BR_91, reprsai.Theil1_91, rndtrabr, 0);
*%theilb(1980, reprsai.BR_80, reprsai.Theil1_80, rndtrabr, 0);


*%theilb(2000, reprsai.BR_00, reprsai.Theil2_00, rdpcr, 1);
%theilb(1991, reprsai.BR_91, reprsai.Theil2_91, rdpcr, 1);
*%theilb(1980, reprsai.BR_80, reprsai.Theil2_80, rdpcr, 1);

%theilw(1980, reprsai.BR_80, reprsai.TMunic1_80, rndtrabr, 0);
%theilw(2000, reprsai.BR_00, reprsai.TMunic1_00, rndtrabr, 0);

PROC EXPORT DATA=reprsai.theil1_00
            OUTFILE= "C:\Alexandre\Artigos\aber\2009\theiltrab_00.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;

PROC EXPORT DATA=reprsai.theil2_00
            OUTFILE= "C:\Alexandre\Artigos\aber\2009\theiltot_00.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;

PROC EXPORT DATA=reprsai.theil1_91
            OUTFILE= "C:\Alexandre\Artigos\aber\2009\theiltrab_91.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;

PROC EXPORT DATA=reprsai.theil2_91
            OUTFILE= "C:\Alexandre\Artigos\aber\2009\theiltot_91.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;

PROC EXPORT DATA=reprsai.theil1_80
            OUTFILE= "C:\Alexandre\Artigos\aber\2009\theiltrab_80.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;

PROC EXPORT DATA=reprsai.theil2_80
            OUTFILE= "C:\Alexandre\Artigos\aber\2009\theiltot_80.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;



/* CRIA ARQUIVO COM INDICADORES MEDIOS POR ANO */
proc sql;
  create table reprsai.tbr_a as

    select 2000 as ano label='Ano', 
		   sum((condativ=2 or condativ=3)*p001p)/sum((condativ<>1)*p001p) as tp format=commax5.3,
		   sum((condativ=3)*p001p)/sum((condativ=2 or condativ=3)*p001p) as td format=commax5.3,
		   sum((condativ=2 and v0450=2)*p001p)/sum((condativ=2)*p001p) as tinfomal format=commax5.3,
		   sum((condativ=2 and v0453<30)*p001p)/sum((condativ=2)*p001p) as tunder format=commax5.3,
		   sum((condativ=2 and idade>=10 and idade<20)*p001p)/sum((condativ=2)*p001p) as po10a19 format=commax5.3,
		   sum((condativ=2 and idade>=20 and idade<30)*p001p)/sum((condativ=2)*p001p) as po20a29 format=commax5.3,
		   sum((condativ=2 and idade>=30 and idade<40)*p001p)/sum((condativ=2)*p001p) as po30a39 format=commax5.3,
		   sum((condativ=2 and idade>=40 and idade<50)*p001p)/sum((condativ=2)*p001p) as po40a49 format=commax5.3,
		   sum((condativ=2 and idade>=50 and idade<60)*p001p)/sum((condativ=2)*p001p) as po50a59 format=commax5.3,
		   sum((condativ=2 and idade>=60)*p001p)/sum((condativ=2)*p001p) as po60 format=commax5.3,
		   sum((condativ=2 and escolar=0)*p001p)/sum((condativ=2)*p001p) as poesc0 format=commax5.3,
		   sum((condativ=2 and escolar=1)*p001p)/sum((condativ=2)*p001p) as poesc1 format=commax5.3,
		   sum((condativ=2 and escolar=2)*p001p)/sum((condativ=2)*p001p) as poesc2 format=commax5.3,
		   sum((condativ=2 and escolar=3)*p001p)/sum((condativ=2)*p001p) as poesc3 format=commax5.3,
		   sum((condativ=2 and sexo=2)*p001p)/sum((condativ=2)*p001p) as pofem format=commax5.3,
		   sum((condativ=2 and cor=1)*p001p)/sum((condativ=2)*p001p) as pobranco format=commax5.3,
		   sum((condativ=2 and sativ=1)*p001p)/sum((condativ=2)*p001p) as poativ1 format=commax5.3,
		   sum((condativ=2 and sativ=2)*p001p)/sum((condativ=2)*p001p) as poativ2 format=commax5.3,
		   sum((condativ=2 and sativ=3)*p001p)/sum((condativ=2)*p001p) as poativ3 format=commax5.3,
		   sum((condativ=2 and sativ=4)*p001p)/sum((condativ=2)*p001p) as poativ4 format=commax5.3,
		   sum((condativ=2 and sativ=5)*p001p)/sum((condativ=2)*p001p) as poativ5 format=commax5.3,
		   sum((condativ=2 and sativ=6)*p001p)/sum((condativ=2)*p001p) as poativ6 format=commax5.3,
		   sum((condativ=2 and occgrp=1)*p001p)/sum((condativ=2)*p001p) as poocc1 format=commax5.3,
		   sum((condativ=2 and occgrp=2)*p001p)/sum((condativ=2)*p001p) as poocc2 format=commax5.3,
		   sum((condativ=2 and occgrp=3)*p001p)/sum((condativ=2)*p001p) as poocc3 format=commax5.3,
		   sum((condativ=2 and occgrp=4)*p001p)/sum((condativ=2)*p001p) as poocc4 format=commax5.3,
		   sum((condativ=2 and occgrp=5)*p001p)/sum((condativ=2)*p001p) as poocc5 format=commax5.3,
		   sum((condativ=2 and occgrp=6)*p001p)/sum((condativ=2)*p001p) as poocc6 format=commax5.3,
		   sum((condativ=2 and occgrp=7)*p001p)/sum((condativ=2)*p001p) as poocc7 format=commax5.3,
		   sum((condativ=2 and occgrp=8)*p001p)/sum((condativ=2)*p001p) as poocc8 format=commax5.3,
		   sum((condativ=2 and occgrp=9)*p001p)/sum((condativ=2)*p001p) as poocc9 format=commax5.3
	from reprsai.br_00

	union

	select 1980 as ano label='Ano', 
		   sum((condativ=2 or condativ=3)*p001p)/sum((condativ<>1)*p001p) as tp format=commax5.3,
		   sum((condativ=3)*p001p)/sum((condativ=2 or condativ=3)*p001p) as td format=commax5.3,
		   sum((condativ=2 and v534=8)*p001p)/sum((condativ=2 and v534 in (2,4,6,8))*p001p) as tinfomal format=commax5.3,
		   sum((condativ=2 and v535 in (1,2))*p001p)/sum((condativ=2 and v535 in (1,2,3,4,5))*p001p) as tunder format=commax5.3,
		   sum((condativ=2 and idade>=10 and idade<20)*p001p)/sum((condativ=2)*p001p) as po10a19 format=commax5.3,
		   sum((condativ=2 and idade>=20 and idade<30)*p001p)/sum((condativ=2)*p001p) as po20a29 format=commax5.3,
		   sum((condativ=2 and idade>=30 and idade<40)*p001p)/sum((condativ=2)*p001p) as po30a39 format=commax5.3,
		   sum((condativ=2 and idade>=40 and idade<50)*p001p)/sum((condativ=2)*p001p) as po40a49 format=commax5.3,
		   sum((condativ=2 and idade>=50 and idade<60)*p001p)/sum((condativ=2)*p001p) as po50a59 format=commax5.3,
		   sum((condativ=2 and idade>=60)*p001p)/sum((condativ=2)*p001p) as po60 format=commax5.3,
		   sum((condativ=2 and escolar=0)*p001p)/sum((condativ=2)*p001p) as poesc0 format=commax5.3,
		   sum((condativ=2 and escolar=1)*p001p)/sum((condativ=2)*p001p) as poesc1 format=commax5.3,
		   sum((condativ=2 and escolar=2)*p001p)/sum((condativ=2)*p001p) as poesc2 format=commax5.3,
		   sum((condativ=2 and escolar=3)*p001p)/sum((condativ=2)*p001p) as poesc3 format=commax5.3,
		   sum((condativ=2 and sexo=2)*p001p)/sum((condativ=2)*p001p) as pofem format=commax5.3,
		   sum((condativ=2 and cor=1)*p001p)/sum((condativ=2)*p001p) as pobranco format=commax5.3,
		   sum((condativ=2 and sativ=1)*p001p)/sum((condativ=2)*p001p) as poativ1 format=commax5.3,
		   sum((condativ=2 and sativ=2)*p001p)/sum((condativ=2)*p001p) as poativ2 format=commax5.3,
		   sum((condativ=2 and sativ=3)*p001p)/sum((condativ=2)*p001p) as poativ3 format=commax5.3,
		   sum((condativ=2 and sativ=4)*p001p)/sum((condativ=2)*p001p) as poativ4 format=commax5.3,
		   sum((condativ=2 and sativ=5)*p001p)/sum((condativ=2)*p001p) as poativ5 format=commax5.3,
		   sum((condativ=2 and sativ=6)*p001p)/sum((condativ=2)*p001p) as poativ6 format=commax5.3,
		   sum((condativ=2 and occgrp=1)*p001p)/sum((condativ=2)*p001p) as poocc1 format=commax5.3,
		   sum((condativ=2 and occgrp=2)*p001p)/sum((condativ=2)*p001p) as poocc2 format=commax5.3,
		   sum((condativ=2 and occgrp=3)*p001p)/sum((condativ=2)*p001p) as poocc3 format=commax5.3,
		   sum((condativ=2 and occgrp=4)*p001p)/sum((condativ=2)*p001p) as poocc4 format=commax5.3,
		   sum((condativ=2 and occgrp=5)*p001p)/sum((condativ=2)*p001p) as poocc5 format=commax5.3,
		   sum((condativ=2 and occgrp=6)*p001p)/sum((condativ=2)*p001p) as poocc6 format=commax5.3,
		   sum((condativ=2 and occgrp=7)*p001p)/sum((condativ=2)*p001p) as poocc7 format=commax5.3,
		   sum((condativ=2 and occgrp=8)*p001p)/sum((condativ=2)*p001p) as poocc8 format=commax5.3,
		   sum((condativ=2 and occgrp=9)*p001p)/sum((condativ=2)*p001p) as poocc9 format=commax5.3
	from reprsai.br_80;



quit;
  
PROC EXPORT DATA=reprsai.tbr_a
            OUTFILE= "f:\Alexandre\artigos\rsai\review\tbr_a.xls" 
            DBMS=EXCEL2000 REPLACE;
RUN;

